@@ -1,9 +1,11 @@
-// Copyright (C) 2008-2013 Conrad Sanderson
-// Copyright (C) 2008-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_det
@@ -45,7 +47,7 @@ det
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  const char sig = method[0];
+  const char sig = (method != NULL) ? method[0] : char(0);
   
   arma_debug_check( ((sig != 's') && (sig != 'f')), "det(): unknown method specified" );
   
@@ -74,7 +76,9 @@ det
   
   const diagmat_proxy<T1> A(X.m);
   
-  const uword N = A.n_elem;
+  arma_debug_check( (A.n_rows != A.n_cols), "det(): given matrix must be square sized" );
+  
+  const uword N = (std::min)(A.n_rows, A.n_cols);
   
   eT val1 = eT(1);
   eT val2 = eT(1);
@@ -109,7 +113,7 @@ det
   {
   arma_extra_debug_sigprint();
   
-  const char sig = method[0];
+  const char sig = (method != NULL) ? method[0] : char(0);
   
   arma_debug_check( ((sig != 's') && (sig != 'f')), "det(): unknown method specified" );
   
@@ -138,7 +142,7 @@ det
   
   const uword N = P.get_n_rows();
   
-  arma_debug_check( (N != P.get_n_cols()), "det(): matrix is not square" );
+  arma_debug_check( (N != P.get_n_cols()), "det(): given matrix must be square sized" );
   
   eT val1 = eT(1);
   eT val2 = eT(1);
@@ -172,7 +176,7 @@ det
   {
   arma_extra_debug_sigprint();
   
-  const char sig = method[0];
+  const char sig = (method != NULL) ? method[0] : char(0);
   
   arma_debug_check( ((sig != 's') && (sig != 'f')), "det(): unknown method specified" );
   
@@ -200,7 +204,7 @@ det
   
   const eT tmp = det(X.m, slow);
   
-  arma_warn( (tmp == eT(0)), "det(): warning: denominator is zero" );
+  if(tmp == eT(0))  { arma_debug_warn("det(): denominator is zero" ); }
   
   return eT(1) / tmp;
   }
@@ -221,7 +225,7 @@ det
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  const char sig = method[0];
+  const char sig = (method != NULL) ? method[0] : char(0);
   
   arma_debug_check( ((sig != 's') && (sig != 'f')), "det(): unknown method specified" );
   
@@ -270,7 +274,7 @@ det
   arma_ignore(junk1);
   arma_ignore(junk2);
   
-  const char sig = method[0];
+  const char sig = (method != NULL) ? method[0] : char(0);
   
   arma_debug_check( ((sig != 's') && (sig != 'f')), "det(): unknown method specified" );
   
