@@ -1,9 +1,11 @@
-// Copyright (C) 2012-2014 Conrad Sanderson
-// Copyright (C) 2012-2014 NICTA (www.nicta.com.au)
+// Copyright (C) 2012-2014 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup memory
@@ -52,7 +54,7 @@ memory::acquire(const uword n_elem)
   {
   arma_debug_check
     (
-    ( n_elem > (std::numeric_limits<size_t>::max() / sizeof(eT)) ),
+    ( size_t(n_elem) > (std::numeric_limits<size_t>::max() / sizeof(eT)) ),
     "arma::memory::acquire(): requested size is too large"
     );
   
@@ -153,7 +155,7 @@ memory::is_aligned(const eT* mem)
   {
   #if (defined(ARMA_HAVE_ICC_ASSUME_ALIGNED) || defined(ARMA_HAVE_GCC_ASSUME_ALIGNED)) && !defined(ARMA_DONT_CHECK_ALIGNMENT)
     {
-    return ((std::ptrdiff_t(mem) & 0x0F) == 0);
+    return (sizeof(std::size_t) >= sizeof(eT*)) ? ((std::size_t(mem) & 0x0F) == 0) : false;
     }
   #else
     {
