@@ -1,9 +1,11 @@
-// Copyright (C) 2008-2011 Conrad Sanderson
-// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2014 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup op_inv
@@ -23,7 +25,7 @@ class op_inv
   inline static void apply(Mat<typename T1::elem_type>& out, const Op<T1,op_inv>& in);
   
   template<typename T1>
-  inline static void apply_diag(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type, T1>& X);
+  inline static bool apply_diagmat(Mat<typename T1::elem_type>& out, const T1& X);
   };
 
 
